# Qrkey

[![PyPI - Version](https://img.shields.io/pypi/v/qrkey.svg)](https://pypi.org/project/qrkey)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qrkey.svg)](https://pypi.org/project/qrkey)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install qrkey
```

## License

`qrkey` is distributed under the terms of the [BSD-3-Clause](https://spdx.org/licenses/BSD-3-Clause.html) license.
